@@ -9,24 +9,40 @@ from .sendfiles import viperunsubscribeconsumer
 
 from .sendfiles import viperproducetotopic
 from .sendfiles import viperproducetotopicbulk
+
+from .sendfiles import viperconsumefromtopicbatch
+
 from .sendfiles import viperconsumefromtopic
+
 from .sendfiles import viperhpdepredict
+from .sendfiles import viperhpdepredictbatch
 
 from .sendfiles import viperhpdeoptimize
+from .sendfiles import viperhpdeoptimizebatch
+
+from .sendfiles import viperstreamcorr
 
 from .sendfiles import viperhpdetraining
+from .sendfiles import viperhpdetrainingbatch
 
 from .sendfiles import viperproducetotopicstream
 
 from .sendfiles import viperpreprocessproducetotopicstream
 
+from .sendfiles import viperpreprocessbatch
+
 from .sendfiles import vipercreatetrainingdata
     
+from .sendfiles import viperstreamquery
+from .sendfiles import viperstreamquerybatch
+
 
 from .sendfiles import vipercreatetopic
 from .sendfiles import viperconsumefromstreamtopic
 from .sendfiles import vipercreatejointopicstreams
-    
+
+from .sendfiles import viperpreprocesscustomjson
+
 from .sendfiles import vipercreateconsumergroup
 from .sendfiles import viperconsumergroupconsumefromtopic
     
@@ -43,7 +59,12 @@ from .sendfiles import vipergroupactivate
 from .sendfiles import vipergroupdeactivate
 
 from .sendfiles import viperanomalytrain
+from .sendfiles import viperanomalytrainbatch
+
 from .sendfiles import viperanomalypredict
+from .sendfiles import viperanomalypredictbatch
+
+from .sendfiles import areyoubusy
 
 
 name = "maadstml"
